==> zio-aws-ec2_2.12-7.21.15.12-sources.jar: zio/aws/ec2/model/StartNetworkInsightsAnalysisRequest.scala <==
package zio.aws.ec2.model
import zio.aws.ec2.model.primitives.{ResourceArn, NetworkInsightsPathId}
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class StartNetworkInsightsAnalysisRequest(
    networkInsightsPathId: NetworkInsightsPathId,
    additionalAccounts: Optional[Iterable[String]] = Optional.Absent,
    filterInArns: Optional[Iterable[ResourceArn]] = Optional.Absent,
    dryRun: Optional[Boolean] = Optional.Absent,
    tagSpecifications: Optional[Iterable[zio.aws.ec2.model.TagSpecification]] =
      Optional.Absent,
    clientToken: String
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.ec2.model.StartNetworkInsightsAnalysisRequest = {
    import StartNetworkInsightsAnalysisRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.ec2.model.StartNetworkInsightsAnalysisRequest
      .builder()
      .networkInsightsPathId(
        NetworkInsightsPathId.unwrap(networkInsightsPathId): java.lang.String
      )
      .optionallyWith(
        additionalAccounts.map(value =>
          value.map { item =>
            item: java.lang.String
          }.asJavaCollection
        )
      )(_.additionalAccounts)
      .optionallyWith(
        filterInArns.map(value =>
          value.map { item =>
            ResourceArn.unwrap(item): java.lang.String
          }.asJavaCollection
        )
      )(_.filterInArns)
      .optionallyWith(dryRun.map(value => value: java.lang.Boolean))(_.dryRun)
      .optionallyWith(
        tagSpecifications.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.tagSpecifications)
      .clientToken(clientToken: java.lang.String)
      .build()
  }
  def asReadOnly
      : zio.aws.ec2.model.StartNetworkInsightsAnalysisRequest.ReadOnly =
    zio.aws.ec2.model.StartNetworkInsightsAnalysisRequest.wrap(buildAwsValue())
}
object StartNetworkInsightsAnalysisRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.ec2.model.StartNetworkInsightsAnalysisRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.ec2.model.StartNetworkInsightsAnalysisRequest =
      zio.aws.ec2.model.StartNetworkInsightsAnalysisRequest(
        networkInsightsPathId,
        additionalAccounts.map(value => value),
        filterInArns.map(value => value),
        dryRun.map(value => value),
        tagSpecifications.map(value =>
          value.map { item =>
            item.asEditable
          }
        ),
        clientToken
      )
    def networkInsightsPathId: NetworkInsightsPathId
    def additionalAccounts: Optional[List[String]]
    def filterInArns: Optional[List[ResourceArn]]
    def dryRun: Optional[Boolean]
    def tagSpecifications
        : Optional[List[zio.aws.ec2.model.TagSpecification.ReadOnly]]
    def clientToken: String
    def getNetworkInsightsPathId: ZIO[Any, Nothing, NetworkInsightsPathId] =
      ZIO.succeed(networkInsightsPathId)
    def getAdditionalAccounts: ZIO[Any, AwsError, List[String]] =
      AwsError.unwrapOptionField("additionalAccounts", additionalAccounts)
    def getFilterInArns: ZIO[Any, AwsError, List[ResourceArn]] =
      AwsError.unwrapOptionField("filterInArns", filterInArns)
    def getDryRun: ZIO[Any, AwsError, Boolean] =
      AwsError.unwrapOptionField("dryRun", dryRun)
    def getTagSpecifications: ZIO[Any, AwsError, List[
      zio.aws.ec2.model.TagSpecification.ReadOnly
    ]] = AwsError.unwrapOptionField("tagSpecifications", tagSpecifications)
    def getClientToken: ZIO[Any, Nothing, String] = ZIO.succeed(clientToken)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.ec2.model.StartNetworkInsightsAnalysisRequest
  ) extends zio.aws.ec2.model.StartNetworkInsightsAnalysisRequest.ReadOnly {
    override val networkInsightsPathId: NetworkInsightsPathId =
      zio.aws.ec2.model.primitives
        .NetworkInsightsPathId(impl.networkInsightsPathId())
    override val additionalAccounts: Optional[List[String]] =
      zio.aws.core.internal
        .optionalFromNullable(impl.additionalAccounts())
        .map(value =>
          value.asScala.map { item =>
            item: String
          }.toList
        )
    override val filterInArns: Optional[List[ResourceArn]] =
      zio.aws.core.internal
        .optionalFromNullable(impl.filterInArns())
        .map(value =>
          value.asScala.map { item =>
            zio.aws.ec2.model.primitives.ResourceArn(item)
          }.toList
        )
    override val dryRun: Optional[Boolean] = zio.aws.core.internal
      .optionalFromNullable(impl.dryRun())
      .map(value => value: Boolean)
    override val tagSpecifications
        : Optional[List[zio.aws.ec2.model.TagSpecification.ReadOnly]] =
      zio.aws.core.internal
        .optionalFromNullable(impl.tagSpecifications())
        .map(value =>
          value.asScala.map { item =>
            zio.aws.ec2.model.TagSpecification.wrap(item)
          }.toList
        )
    override val clientToken: String = impl.clientToken(): String
  }
  def wrap(
      impl: software.amazon.awssdk.services.ec2.model.StartNetworkInsightsAnalysisRequest
  ): zio.aws.ec2.model.StartNetworkInsightsAnalysisRequest.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-ec2_2.13-5.17.102.8-sources.jar: zio/aws/ec2/model/StartNetworkInsightsAnalysisRequest.scala <==
package zio.aws.ec2.model
import zio.aws.ec2.model.primitives.{ResourceArn, NetworkInsightsPathId}
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class StartNetworkInsightsAnalysisRequest(
    networkInsightsPathId: NetworkInsightsPathId,
    filterInArns: Option[Iterable[ResourceArn]] = None,
    tagSpecifications: Option[Iterable[zio.aws.ec2.model.TagSpecification]] =
      None,
    clientToken: String
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.ec2.model.StartNetworkInsightsAnalysisRequest = {
    import StartNetworkInsightsAnalysisRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.ec2.model.StartNetworkInsightsAnalysisRequest
      .builder()
      .networkInsightsPathId(
        NetworkInsightsPathId.unwrap(networkInsightsPathId): java.lang.String
      )
      .optionallyWith(
        filterInArns.map(value =>
          value.map { item =>
            ResourceArn.unwrap(item): java.lang.String
          }.asJavaCollection
        )
      )(_.filterInArns)
      .optionallyWith(
        tagSpecifications.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.tagSpecifications)
      .clientToken(clientToken: java.lang.String)
      .build()
  }
  def asReadOnly
      : zio.aws.ec2.model.StartNetworkInsightsAnalysisRequest.ReadOnly =
    zio.aws.ec2.model.StartNetworkInsightsAnalysisRequest.wrap(buildAwsValue())
}
object StartNetworkInsightsAnalysisRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.ec2.model.StartNetworkInsightsAnalysisRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.ec2.model.StartNetworkInsightsAnalysisRequest =
      zio.aws.ec2.model.StartNetworkInsightsAnalysisRequest(
        networkInsightsPathId,
        filterInArns.map(value => value),
        tagSpecifications.map(value =>
          value.map { item =>
            item.asEditable
          }
        ),
        clientToken
      )
    def networkInsightsPathId: NetworkInsightsPathId
    def filterInArns: Option[List[ResourceArn]]
    def tagSpecifications
        : Option[List[zio.aws.ec2.model.TagSpecification.ReadOnly]]
    def clientToken: String
    def getNetworkInsightsPathId: ZIO[Any, Nothing, NetworkInsightsPathId] =
      ZIO.succeed(networkInsightsPathId)
    def getFilterInArns: ZIO[Any, AwsError, List[ResourceArn]] =
      AwsError.unwrapOptionField("filterInArns", filterInArns)
    def getTagSpecifications: ZIO[Any, AwsError, List[
      zio.aws.ec2.model.TagSpecification.ReadOnly
    ]] = AwsError.unwrapOptionField("tagSpecifications", tagSpecifications)
    def getClientToken: ZIO[Any, Nothing, String] = ZIO.succeed(clientToken)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.ec2.model.StartNetworkInsightsAnalysisRequest
  ) extends zio.aws.ec2.model.StartNetworkInsightsAnalysisRequest.ReadOnly {
    override val networkInsightsPathId: NetworkInsightsPathId =
      zio.aws.ec2.model.primitives
        .NetworkInsightsPathId(impl.networkInsightsPathId())
    override val filterInArns: Option[List[ResourceArn]] = scala
      .Option(impl.filterInArns())
      .map(value =>
        value.asScala.map { item =>
          zio.aws.ec2.model.primitives.ResourceArn(item)
        }.toList
      )
    override val tagSpecifications
        : Option[List[zio.aws.ec2.model.TagSpecification.ReadOnly]] = scala
      .Option(impl.tagSpecifications())
      .map(value =>
        value.asScala.map { item =>
          zio.aws.ec2.model.TagSpecification.wrap(item)
        }.toList
      )
    override val clientToken: String = impl.clientToken(): String
  }
  def wrap(
      impl: software.amazon.awssdk.services.ec2.model.StartNetworkInsightsAnalysisRequest
  ): zio.aws.ec2.model.StartNetworkInsightsAnalysisRequest.ReadOnly =
    new Wrapper(impl)
}
